/**
*Copyright 2018 Mark Butler
*
*This file is part of Hexagon Grid Library.
*
*Hexagon Grid Library is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
*
*Hexagon Grid Library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
*You should have received a copy of the GNU Lesser General Public License along with Hexagon Grid Library. If not, see http://www.gnu.org/licenses/.const

/**
* Point
*
* The x, y coordinates are used to calculate line of sight, range, bearing and unit facing.
*
* @class Point
* @constructor
*/
function Point() {

	this.x = 0;
	this.y = 0;

	if ( Point.arguments.length == 1
			&& Point.arguments[0].constructor == Point ) {

		this.x = Point.arguments[0].x;
		this.y = Point.arguments[0].y;
	}

	if ( Point.arguments.length == 2
			&& Point.arguments[0].constructor == Number
			&& Point.arguments[1].constructor == Number ) {

		this.x = Point.arguments[0];
		this.y = Point.arguments[1];
	}
}

/**
* method to see if two points are the same
*
* @method Point.equals
* @memberof Point
* @param point {Point} another point
* @return {boolean} true/false
*/
Point.prototype.equals = function(point)
{
		var isEqual;
		isEqual = false;

		if ( this.x == point.getX() && this.y == point.getY() )
		{
			isEqual = true;
		}

		return isEqual;
}

/**
* method to get x coordinate of a Point
*
* @method Point.getX
* @return {integer} x coordinate
*/
Point.prototype.getX = function()
{
	return this.x;
}

/**
* method to get y coordinate of a Point
*
* @method Point.getY
* @return {integer} y coordinate
*/
Point.prototype.getY = function() {

	return this.y;
}

/**
* method to set x, y coordinate of a Point
*
* @method Point.setXY
* @param x {integer} x coordinate
* @param y {integer} y coordinate
*/
Point.prototype.setXY = function(x, y) {

	this.x = x;
	this.y = y;
}

module.exports = Point;
